/*******************************************************************************
Description:		Wealth tax modelling: progressive one-off tax
					
Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

use "$tempdata\sample_for_analysis.dta", clear

**********************************
*****ONE OFF PROGRESSIVE TAX *****
**********************************

local base_flag = "$base_flag"

*Matrix for results - one for each set of rates
matrix indiv_oneoffincr1 = J(2,9,.)
mat coln indiv_oneoffincr1 = individual1_hh2 assets taxpayers revenue rate_500k rate_1m rate_2m rate_5m rate_10m 

*Matrix for results
matrix indiv_oneoffincr2 = J(2,9,.)
mat coln indiv_oneoffincr2 = individual1_hh2 assets taxpayers revenue rate_500k rate_1m rate_2m rate_5m rate_10m 

*Excel sheet for output
putexcel set "$output\outputs.xlsx", modify sheet("indiv_oneoffincr`base_flag'")

********************
***CALCS**
********************

foreach rates in 1 2 { //two sets of rates, one starting at 500k one starting at 1m

	*Person basis
	matrix indiv_oneoffincr`rates'[1,1] = 1

	*Rates
	if `rates' == 1 scalar rate_500k = $prate_one_500
	if `rates' == 1 scalar rate_1m = $prate_one_1m
	if `rates' == 1 scalar rate_2m = $prate_one_2m
	if `rates' == 1 scalar rate_5m = $prate_one_5m
	if `rates' == 1 scalar rate_10m = $prate_one_10m

	if `rates' == 2 scalar rate_500k = $prate2_one_500
	if `rates' == 2 scalar rate_1m = $prate2_one_1m
	if `rates' == 2 scalar rate_2m = $prate2_one_2m
	if `rates' == 2 scalar rate_5m = $prate2_one_5m
	if `rates' == 2 scalar rate_10m = $prate2_one_10m
		
	*Average tax rate 
	if `rates' == 1 {
	g atr = 0 if $wealth_var < 1000000
	replace atr = (($wealth_var - 1000000)*rate_1m)/$wealth_var if $wealth_var > 1000000 & $wealth_var < 2000000
	replace atr = (($wealth_var - 2000000)*rate_2m + (2000000-1000000)*rate_1m)/$wealth_var if $wealth_var > 2000000 & $wealth_var < 5000000
	replace atr = (($wealth_var - 5000000)*rate_5m + (5000000-2000000)*rate_2m + (2000000-1000000)*rate_1m)/$wealth_var if $wealth_var > 5000000 & $wealth_var < 10000000
	replace atr = (($wealth_var - 10000000)*rate_10m + (10000000-5000000)*rate_5m + (5000000-2000000)*rate_2m + (2000000-1000000)*rate_1m)/$wealth_var if $wealth_var > 10000000
	}

	if `rates' == 2 {
	g atr = 0 if $wealth_var < 500000
	replace atr = (($wealth_var - 500000)*rate_500k)/$wealth_var if $wealth_var > 500000 & $wealth_var < 1000000
	replace atr = (($wealth_var - 1000000)*rate_1m + (1000000-500000)*rate_500k)/$wealth_var if $wealth_var > 1000000 & $wealth_var < 2000000
	replace atr = (($wealth_var - 2000000)*rate_2m + (2000000-1000000)*rate_1m + (1000000-500000)*rate_500k)/$wealth_var if $wealth_var > 2000000 & $wealth_var < 5000000
	replace atr = (($wealth_var - 5000000)*rate_5m + (5000000-2000000)*rate_2m + (2000000-1000000)*rate_1m + (1000000-500000)*rate_500k)/$wealth_var if $wealth_var > 5000000 & $wealth_var < 10000000
	replace atr = (($wealth_var - 10000000)*rate_10m + (10000000-5000000)*rate_5m + (5000000-2000000)*rate_2m + (2000000-1000000)*rate_1m + (1000000-500000)*rate_500k)/$wealth_var if $wealth_var > 10000000
	}

	*No adjustment for evasion right now, we allow for 10% evasion of the estimated revenue at the end
	g double wealth_adj = $wealth_var

	*Assets in tax base (£bn)
	if `rates' == 1 {
	g taxable = wealth_adj - 1000000
	}
	if `rates' == 2 {
	g taxable = wealth_adj - 500000
	}
	sum taxable [weight = xs_pers] if taxable > 0
	di r(sum)/1000000000
	matrix indiv_oneoffincr`rates'[1,2] = r(sum)/1000000000

	if `rates' == 1 {
	g tax_due_500k = 0
	}
	if `rates' == 2 {
	g tax_due_500k = .
	replace tax_due_500k = 0 if wealth_adj < 500000
	replace tax_due_500k = (wealth_adj - 500000)*rate_500k if wealth_adj >= 500000
	replace tax_due_500k = 500000*rate_500k if wealth_adj > 1000000
	}

	g tax_due_1m = .
	replace tax_due_1m = 0 if wealth_adj < 1000000
	replace tax_due_1m = (wealth_adj - 1000000)*rate_1m if wealth_adj >= 1000000
	replace tax_due_1m = 1000000*rate_1m if wealth_adj > 2000000

	g tax_due_2m = .
	replace tax_due_2m = 0 if wealth_adj < 2000000
	replace tax_due_2m = (wealth_adj - 2000000)*rate_2m if wealth_adj >= 2000000
	replace tax_due_2m = 3000000*rate_2m if wealth_adj > 5000000

	g tax_due_5m = .
	replace tax_due_5m = 0 if wealth_adj < 5000000
	replace tax_due_5m = (wealth_adj - 5000000)*rate_5m if wealth_adj >= 5000000
	replace tax_due_5m = 5000000*rate_5m if wealth_adj > 10000000

	g tax_due_10m = .
	replace tax_due_10m = 0 if wealth_adj < 10000000
	replace tax_due_10m = (wealth_adj - 10000000)*rate_10m if wealth_adj >= 10000000


	*Record rates
	matrix indiv_oneoffincr`rates'[1,5] = rate_500k //marginal rates above each threshold
	matrix indiv_oneoffincr`rates'[1,6] = rate_1m
	matrix indiv_oneoffincr`rates'[1,7] = rate_2m
	matrix indiv_oneoffincr`rates'[1,8] = rate_5m
	matrix indiv_oneoffincr`rates'[1,9] = rate_10m

	*Tax due
	g tax_due = tax_due_500k + tax_due_1m + tax_due_2m + tax_due_5m + tax_due_10m
	sum tax_due [weight = xs_pers] if (tax_due > 0 & tax_due ~= .)
	matrix indiv_oneoffincr`rates'[1,3] = r(sum_w) //number of individuals paying tax 


	*Total revenue (£bn)
	sum tax_due [weight = xs_pers] if (tax_due > 0 & tax_due ~= .)
	di r(sum)/1000000000
	matrix indiv_oneoffincr`rates'[1,4] = 0.9*(r(sum)/1000000000) //total revenue in £billions, after accounting for evasion


	drop tax_due tax_due*m tax_due_500k atr wealth_adj  taxable 

}
*Output matrix
putexcel A2 = matrix(indiv_oneoffincr1), names 
putexcel A5 = matrix(indiv_oneoffincr2), names
	
	
