/******************************************************************
Description:		Code to roughly estimate effect of equalising dividend income tax rate (implicitly, also removing allowances & reliefs)

Uses: raw SPI data for 2017 ("2017_spi.dta")
******************************************************************/


clear all
set mo off, perm
pause on

***************
*****SETUP*****
***************
use "$spidata\2017_spi.dta", clear

rename *, lower
	
*******CALCULATING TAX DIRECTLY ON DIVIDENDS*******
	
*Incidence
g gross_profits = dividends/(1 - 0.2)
g ct_paid = gross_profits - dividends


*Calculate tax paid on dividends according to B/H/A flag 

*BR/HR/AR according to variable MAR
g band = substr(mar, 3, 1)
replace band = "" if mar == "NONTP"

*Dividends tax rates 2016-17
*Dividend basic rate 7.5%
*Dividend higher rate 32.5%
*Dividend additional rate 38.1%
*Personal allowance: £5000

g div_tax_paid = dividends*0.075 if band == "B"
replace div_tax_paid = dividends*0.325 if band == "H"
replace div_tax_paid = dividends*0.381 if band == "A"

*Apply income tax rates

g div_tax_eq = dividends*0.2 if band == "B"
replace div_tax_eq = dividends*0.4 if band == "H"
replace div_tax_eq = dividends*0.45 if band == "A"

sum div_tax_eq [w = fact]
scalar headline = r(sum)

sum div_tax_paid [w = fact]	
scalar paid = r(sum)

di (headline - paid)/1000000000	
	

*******DISTRIBUTIONAL ASPECTS OF REFORM*******


egen inc_band = cut(ti), at(0, 11000, 32000, 150000)
replace inc_band = 150000 if (ti >= 150000 & ti ~= .)

*Increase in dividends tax paid

*Banded method
g div_tax_incr = div_tax_eq - div_tax_paid 
table inc_band [pw = fact], c(mean div_tax_incr min div_tax_incr p50 div_tax_incr max div_tax_incr)
table inc_band [pw = fact] if dividends > 0, c(mean div_tax_incr min div_tax_incr p50 div_tax_incr max div_tax_incr)
