/*******************************************************************************
Description:		Wealth tax modelling: IHT distributional analysis

Uses: IHT variables saved in step 11.model_iht_reforms.do (in iht_for_analysis.dta)
*******************************************************************************/


****************************************
***DISTRIBUTIONAL EFFECTS OF IHT REFORM
****************************************
use "$tempdata\iht_for_analysis.dta", clear

keep ihtpayer* deathweight agegroup* sex wealth_* gor taxdue*

*Redefine agegroups
g age_analysis = agegroup
replace age_analysis = 1 if agegroup_detail <= 4
lab define age_analysis 1 "Under 19" 2 "19-24" 3 "25-34" 4 "35-44" 5 "45-54" 6 "55-64" 7 "65-74" 8 "75+"
lab values age_analysis age_analysis
drop agegroup agegroup_detail

*Bands of wealth by reformed (comprehensive) IHT wealth
egen ihtbuckets = cut(wealth_reformed), at(650000, 800000, 1000000, 2000000, 5000000)

*Reforms to loop through
global reforms _actual _incbusiness_oldth _incpension_oldth _reformed_oldth _reformed _reformed_lower

*Set indicator for whether a taxpayer under the reformed system with a reduced rate
g ihtpayer_reformed_lower = ihtpayer_reformed_oldth

*Tax due and number of taxpayers by wealth bucket.
foreach ref in $reforms { 
preserve
keep if ihtpayer`ref' == 1
collapse (mean) taxdue`ref' (sum) ihtpayer`ref' total = taxdue`ref' [pw=deathweight], by(ihtbuckets)
export excel "$output\ihtanalysis.xlsx", sheet("Ave `ref'", modify) cell(A2) firstrow(var)
restore
}
