/*******************************************************************************
Description:		Wealth tax modelling: flat tax annual 
					
Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/


use "$tempdata\sample_for_analysis.dta", clear

********************
*****FLAT RATE *****
***SET PARAMETERS***
********************


foreach elasticity in 0 7 17 {

	*Set: 
	*thresholds - 250k, 500k, 1m, 2m, 5m, 10m
	global thresholds 250000 500000 1000000 2000000 5000000 10000000

	*Wealth variable chosen in 3.define_sample.do
	local base_flag = "$base_flag"


	*Level of evasion (label carried across to excel sheets)
	if `elasticity' == 0 {
		local evasion_flag = "none"
	}
	if `elasticity' == 7 {
		local evasion_flag = "low"
	}
	if `elasticity' == 17 {
		local evasion_flag = "high"
	}

	*Matrix for results
	matrix indiv_flatfixed = J(6,6,.)
	mat coln indiv_flatfixed = individual1_hh2 taxthreshold assets taxpayers revenue rate
	********************

	********************
	***CALCS***
	********************

	local row = 0

	*Excel sheet for output
	putexcel set "$output\outputs.xlsx", modify sheet("indiv_flat`base_flag' `evasion_flag'")

	foreach flat_threshold in $thresholds { 

		local row = `row' + 1

		*Person basis
		matrix indiv_flatfixed[`row',1] = 1
		
		*Threshold
		matrix indiv_flatfixed[`row',2] = `flat_threshold'
		
		*Rates for raising £10bn 
		if `flat_threshold' == 250000 local rate = $frate_an_250
		if `flat_threshold' == 500000 local rate = $frate_an_500
		if `flat_threshold' == 1000000 local rate = $frate_an_1m
		if `flat_threshold' == 2000000 local rate = $frate_an_2m
		if `flat_threshold' == 5000000 local rate = $frate_an_5m
		if `flat_threshold' == 10000000 local rate = $frate_an_10m	
		
		*Average tax rate
		g double atr = 0 if $wealth_var < `flat_threshold'
		replace atr = ($wealth_var - `flat_threshold')*`rate'/$wealth_var if $wealth_var > `flat_threshold'
		
		
		*Adjust wealth to account for evasion  based on average tax rate
		g double evasion = `elasticity'*(atr/0.01)/100
		g double wealth_adj = ${wealth_var}*(1-evasion)
		
		
		*Assets in tax base (£bn)
		g double taxable = wealth_adj - `flat_threshold'
		sum taxable [weight=xs_pers] if taxable > 0
		di r(sum)/1000000000 
		matrix indiv_flatfixed[`row',3] = r(sum)/1000000000 //total taxable wealth in billions
		
		*Calculate taxpayers
		g double tax_due = 0
		replace tax_due = (wealth_adj - `flat_threshold')*`rate' if wealth_adj > `flat_threshold'
		sum tax_due [weight=xs_pers] if tax_due > 0 
		matrix indiv_flatfixed[`row',4] = r(sum_w) //number of individuals paying tax 
		
		*Revenue (£bn))
		g double revenue = `rate'*taxable
		sum revenue [weight = xs_pers] if taxable > 0
		di r(sum)/1000000000
		matrix indiv_flatfixed[`row',5] = r(sum)/1000000000 //total revenue in £billions
		
		*Rate 
		matrix indiv_flatfixed[`row',6] = `rate'
		
		drop tax_due atr wealth_adj evasion taxable revenue

}

*Output matrix, low
putexcel A2=matrix(indiv_flatfixed), names 

}
