/*******************************************************************************
Description:		Wealth tax modelling: flat tax one-off 

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

use "$tempdata\sample_for_analysis.dta", clear


***************************
*****ONE OFF FLAT TAX *****
***************************

*Set: 
*thresholds - 250k, 500k, 1m, 2m, 5m, 10m
global thresholds 250000 500000 1000000 2000000 5000000 10000000

local base_flag = "$base_flag"

*Matrix for results
matrix indiv_oneoffflat1 = J(6,6,.)
mat coln indiv_oneoffflat1 = individual1_hh2 taxthreshold assets taxpayers revenue rate
********************

*Matrix for results
matrix indiv_oneoffflat2 = J(6,6,.)
mat coln indiv_oneoffflat2 = individual1_hh2 taxthreshold assets taxpayers revenue rate
********************

foreach rates in 1 2 { //two sets of rates: one generating £250bn after evasion, one with all 5%


********************
***CALCS***
********************

local row = 0

*Excel sheet for output
putexcel set "$output\outputs.xlsx", modify sheet("indiv_oneoffflat`base_flag'")

foreach flat_threshold in $thresholds { 

	local row = `row' + 1

	*Person basis
	matrix indiv_oneoffflat`rates'[`row',1] = 1
	
	*Threshold
	matrix indiv_oneoffflat`rates'[`row',2] = `flat_threshold'
	
	
	*Rates for raising £280bn (£250bn after evasion acc. Ed Troup) //may automate later
	if `flat_threshold' == 250000 &`rates' == 1 local rate = $frate_one_250
	if `flat_threshold' == 500000 &`rates' == 1 local rate = $frate_one_500
	if `flat_threshold' == 1000000 &`rates' == 1 local rate = $frate_one_1m
	if `flat_threshold' == 2000000 &`rates' == 1 local rate = $frate_one_2m
	if `flat_threshold' == 5000000 &`rates' == 1 local rate = $frate_one_5m
	if `flat_threshold' == 10000000 &`rates' == 1 local rate = $frate_one_10m
	
	*Rates 5%
	if `flat_threshold' == 250000 &`rates' == 2 local rate = 0.05
	if `flat_threshold' == 500000 &`rates' == 2 local rate = 0.05
	if `flat_threshold' == 1000000 &`rates' == 2 local rate = 0.05
	if `flat_threshold' == 2000000 &`rates' == 2 local rate = 0.05
	if `flat_threshold' == 5000000 &`rates' == 2 local rate = 0.05
	if `flat_threshold' == 10000000 &`rates' == 2 local rate = 0.05
	
	
	*Average tax rate
	g atr = 0 if $wealth_var < `flat_threshold'
	replace atr = ($wealth_var - `flat_threshold')*`rate'/$wealth_var if $wealth_var > `flat_threshold'
	
	*No adjustment for evasion right now, we allow for 10% evasion of the estimated revenue at the end
	g wealth_adj = $wealth_var
	
	*Assets in tax base (£bn)
	g taxable = wealth_adj - `flat_threshold'
	sum taxable [weight=xs_pers] if taxable > 0
	di r(sum)/1000000000 
	matrix indiv_oneoffflat`rates'[`row',3] = r(sum)/1000000000 //total taxable wealth in billions
	
	*Calculate taxpayers
	g tax_due = 0
	replace tax_due = (wealth_adj - `flat_threshold')*`rate' if wealth_adj > `flat_threshold'
	sum tax_due [weight=xs_pers] if tax_due > 0 
	matrix indiv_oneoffflat`rates'[`row',4] = r(sum_w) //number of individuals paying tax 
	
	*Revenue (£bn))
	g double revenue = `rate'*taxable
	sum revenue [weight = xs_pers] if taxable > 0
	di r(sum)/1000000000
	matrix indiv_oneoffflat`rates'[`row',5] = 0.9*(r(sum)/1000000000) //total revenue in £billions, after acounting for evasion 
	
	*Rate 
	matrix indiv_oneoffflat`rates'[`row',6] = `rate'
	
	*Clean up
	drop tax_due atr wealth_adj taxable revenue

}
}

*Output matrix, low
putexcel A2=matrix(indiv_oneoffflat1), names 
putexcel A11 = matrix(indiv_oneoffflat2), names
