/*******************************************************************************
Description:		STRL prep: impute missing info by individual (fill in the blanks for revenue modelling)

Uses:				Individualised STRL data (one row per individual)
					Bucket level data for share resident, share national. Created in STRL-1-bucket_rank_level_averages.do.
*******************************************************************************/

**Required variables in individual-level data: 
	*age = derived from Year of Birth (provided to us by the compiler of the STRL) - not needed if $using_companies_house == 0
	*sex (asssigned manually)
	*ukresident = whether UK resident (1/0) (from Companies House) - not needed if $using_companies_house == 0
	*britishnational = whether British national (1/0) (from Companies House) - not needed if $using_companies_house == 0
	*num_named = number of named individuals in that entry of the STRL
	*worth_rank = published worth for that entry of the STRL

*Required variables in bucket-level data: (if using companies house data only) 
	*pct_resident = share (decimal) UK resident
	*pct_british = share (decimal) british national 
	*over80 = share (decimal) over the age of 80

use "$cleanstrl\strl_2020_clean_byindividual.dta", clear

g sex = -male + 2

*Allocate rich list entries to buckets by rank 
local steps = 50
local top = 1000 - `steps'
g bucket =.
forval t = 0(`steps')`top'{
replace bucket = (`t')/`steps' + 1 if item_id_richlist> = `t' & item_id_richlist < `t' + `steps' 
}

if $using_companies_house == 1 {
	*Merge to bucket-level data (for imputing missing info)
	merge m:1 bucket using "$cleanstrl\strl_info_by_bucket.dta", nogen

	*Resident and british
	g resident = ukresident
	g british = britishnational

	*Randomly generate missing residence/nationality info (currently around 140 missing)
	replace resident = rbinomial(1, pct_resident) if missing(resident) //will be random each time code is run (currently)
	replace british = rbinomial(1, pct_british) if missing(british)


	*Age
	sum age if age < 80, de
	g age_80 = rbinomial(1,over80) if missing(age)
	replace age = age_80*80 if missing(age)
	replace age = r(p50) if age == 0


	*Agegroup (matches WAS)
	g agegroup_detail = 1 if age <= 5
	replace agegroup_detail = 2 if age >=5 & age <=9
	replace agegroup_detail = 3 if age >=10 & age <=14
	replace agegroup_detail = 4 if age >=15 & age <=19
	replace agegroup_detail = 5 if age >=20 & age <=24
	replace agegroup_detail = 6 if age >=25 & age <=29
	replace agegroup_detail = 7 if age >=30 & age <=34
	replace agegroup_detail = 8 if age >=35 & age <=39
	replace agegroup_detail = 9 if age >=40 & age <=44
	replace agegroup_detail = 10 if age >=45 & age <=49
	replace agegroup_detail = 11 if age >=50 & age <=54
	replace agegroup_detail = 12 if age >=55 & age <=59
	replace agegroup_detail = 13 if age >=60 & age <=64
	replace agegroup_detail = 14 if age >=65 & age <=69
	replace agegroup_detail = 15 if age >=70 & age <=74
	replace agegroup_detail = 16 if age >=75 & age <= 79
	replace agegroup_detail = 17 if age>=80

	*Divide wealth between number of named individuals
	g worth = worth_rank/num_named
	lab var worth "Wealth per individual"

	drop age_80 over80 bucket pct_* bucket_pop britishnational ukresident worth_rank male
}
else {
	*Divide wealth between number of named individuals
	g worth = worth_rank/num_named
	lab var worth "Wealth per individual"

	drop worth_rank male
}

save "$tempdata\strl_2020_clean_imputed.dta", replace
